### 알림

##### 텔레그램

  * @BotFather 에게서 Bot 생성
  * https://api.telegram.org/bot봇토큰/getUpdates 접속
  * 본인의 봇과 대화
  * https://api.telegram.org/bot봇토큰/getUpdates 접속
   "from":{"id":879500000, 숫자가 본인의 Chat ID
